@@ -1,11 +1,11 @@
 /*
- * Copyright 2006 Nick White
+ * Copyright 2006,2008 Nick White
  *
  * This file is part of GetHT
- * 
- * GetHT is free software; you can redistribute it and/or modify
+ *
+ * GetHT is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * GetHT is distributed in the hope that it will be useful,
@@ -14,13 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GetHT; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
- *
+ * along with GetHT.  If not, see <http://www.gnu.org/licenses/>.
+ * 
  */
 
-/* all sizes are in bytes and are child-inclusive */
-
 typedef struct
 {
 	int year;
@@ -45,15 +42,6 @@ typedef struct
 	int no_of_items;
 } sec;
 
-typedef struct
-{
-	char uri[512];
-	char title[512];
-	char comment[512];
-	char preview_uri[512];
-	int size;
-} med;
-
 typedef struct
 {
 	char preview_uri[512];
@@ -62,16 +50,10 @@ typedef struct
 	issdates date;
 	sec ** section;
 	int no_of_sections;
-	med ** media;
-	int no_of_media;
 } iss;
 
 iss ** parsetoc(char *filepath, int * iss_no);
-iss ** parsemedia(char * filepath, iss ** issue, int * no_of_issues);
-
-med ** parsemediagz(char * media_path, int * no_of_media);
 
 iss ** assignnew_iss(iss ** issue, int *no_of_issues);
 sec ** assignnew_sec(sec ** section, int * no_of_sections);
 it ** assignnew_it(it ** item, int * no_of_items);
-med ** assignnew_med(med ** media, int * no_of_media);
